@@ -38,7 +38,7 @@ BookmarkSelector::BookmarkSelector(URLNavigator* parent) :
     URLButton(parent),
     m_selectedIndex(0)
 {
-    setFocusPolicy(TQ_NoFocus);
+    setFocusPolicy(TQWidget::NoFocus);
 
     m_bookmarksMenu = new TQPopupMenu(this);
 
