@@ -432,11 +432,10 @@ void Dolphin::createFile()
     KSortableValueList<CreateFileEntry, TQString>::ConstIterator it = m_createFileTemplates.begin();
     KSortableValueList<CreateFileEntry, TQString>::ConstIterator end = m_createFileTemplates.end();
 
-    const TQString senderName(TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name());
     bool found = false;
     CreateFileEntry entry;
     while (!found && (it != end)) {
-        if ((*it).index() == senderName) {
+        if ((*it).index() == sender()->name()) {
             entry = (*it).value();
             found = true;
         }
