@@ -498,7 +498,7 @@ void DolphinDetailsView::slotActivationUpdate()
     TQObjectListIterator it(list);
     TQObject* object = 0;
     while ((object = it.current()) != 0) {
-        if (object->inherits(TQWIDGET_OBJECT_NAME_STRING)) {
+        if (object->inherits("TQWidget")) {
             TQWidget* widget = TQT_TQWIDGET(object);
             widget->update();
         }
@@ -716,7 +716,7 @@ void DolphinDetailsView::DolphinListViewItem::paintCell(TQPainter* painter,
                                                         int alignment)
 {
     const TQListView* view = listView();
-    const bool isActive = TQT_BASE_OBJECT(view->parent()) == TQT_BASE_OBJECT(Dolphin::mainWin().activeView());
+    const bool isActive = (view->parent() == Dolphin::mainWin().activeView());
     if (isSelected()) {
         // Per default the selection is drawn above the whole width of the item. As a consistent
         // behavior with the icon view is wanted, only the the column containing the file name
