@@ -39,7 +39,7 @@ class KURL;
  * @author Peter Penz
  */
 class DolphinStatusBar : public TQHBox {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
