@@ -58,7 +58,7 @@ DolphinView::DolphinView(TQWidget *parent,
     m_fileCount(0),
     m_filterBar(0)
 {
-    setFocusPolicy(TQ_StrongFocus);
+    setFocusPolicy(TQWidget::StrongFocus);
     m_topLayout = new TQVBoxLayout(this);
 
     Dolphin& dolphin = Dolphin::mainWin();
