@@ -160,7 +160,7 @@ void InfoSidebarPage::showItemInfo()
                                            TDEIcon::NoGroup,
                                            TDEIcon::SizeEnormous);
         m_preview->setPixmap(icon);
-        m_name->setText(i18n("%n items selected", "%n items selected", selectedItems->count()));
+        m_name->setText(i18n("%n item selected", "%n items selected", selectedItems->count()));
     }
     else if (!applyBookmark()) {
         // try to get a preview pixmap from the item...
@@ -536,7 +536,7 @@ ServiceButton::ServiceButton(const TQIconSet& icon,
     m_index(index)
 {
     setEraseColor(colorGroup().background());
-    setFocusPolicy(TQ_NoFocus);
+    setFocusPolicy(TQWidget::NoFocus);
     connect(this, TQT_SIGNAL(released()),
             this, TQT_SLOT(slotReleased()));
 }
