@@ -42,7 +42,7 @@ class KLineEdit;
  */
 class RenameDialog : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
