@@ -30,7 +30,7 @@
  */
 class SettingsPageBase : public TQWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
