@@ -37,7 +37,7 @@ URLButton::URLButton(URLNavigator* parent)
   m_displayHint(0),
   m_urlNavigator(parent)
 {
-    setFocusPolicy(TQ_NoFocus);
+    setFocusPolicy(TQWidget::NoFocus);
     setSizePolicy(TQSizePolicy::Maximum, TQSizePolicy::Fixed);
     setMinimumHeight(parent->minimumHeight());
 
